@@ -781,7 +781,7 @@ int main(int argc, char **argv){
     close (dfw);    /// close target
     free(bitmap);   /// free bitmp
     close_pui(pui);
-    printf("Cloned successfully.\n");
+    fprintf(stderr, "Cloned successfully.\n");
     if(opt.debug)
         close_log();
 #ifdef MEMTRACE
